extern double P_A[3][3], P_T[3][3];
extern double A_E[3][3], T_E[3][3];
extern double E_G[3][3];

extern double inv_P_A[3][3], inv_P_T[3][3];
extern double inv_A_E[3][3], inv_T_E[3][3];
extern double inv_E_G[3][3];
